﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Data.OleDb;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;

namespace NoteBook
{
  public partial class FormMain : Form
  {
    public FormMain()
    {
      InitializeComponent();
    }
    private OleDbConnection cn;
    private DataSet ds = new DataSet();
    private OleDbDataAdapter daContact;
    private OleDbDataAdapter daPhone;
    private OleDbDataAdapter daTypePhone;
    private OleDbDataAdapter daPhoneAll;
    private BindingSource bsContact     = new BindingSource();
    private BindingSource bsPhone       = new BindingSource();
    private BindingSource bsTypePhone   = new BindingSource();
    private BindingSource bsPhoneAll    = new BindingSource();

    private void DBcon(String DBname)
    {
      cn = new OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0; Data Source=" + Application.StartupPath +
                                "\\\\" + DBname);
      try
      {
        cn.Open();
      }
      catch 
      {
        MessageBox.Show("Error " + "\"" + DBname + "\"", "Error",
                         MessageBoxButtons.OK, MessageBoxIcon.Error);
        Environment.Exit(1);
      }
    }

    private void TuningDgv()
    {
      dgvContact.ColumnHeadersDefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleCenter;
    }

    private void FillTables()
    {
      daContact.Fill(ds.Tables["Contact"]);
      daPhone.Fill(ds.Tables["Phone"]);
      daTypePhone.Fill(ds.Tables["TypePhone"]);
      daPhoneAll.Fill(ds.Tables["PhoneAll"]);
      TuningDgv();
    }

    private void MakeStructureTable()
    {
      ds.Tables.Add("Contact");
      daContact = new OleDbDataAdapter("SELECT * FROM tblContact", cn);
      daContact.FillSchema(ds.Tables["Contact"], SchemaType.Mapped);
// ------------------------------------------------
      ds.Tables.Add("Phone");
      daPhone = new OleDbDataAdapter("SELECT * FROM tblPhone", cn);
      daPhone.FillSchema(ds.Tables["Phone"], SchemaType.Mapped);
// -----------------------------------------------
      ds.Tables.Add("TypePhone");
      daTypePhone = new OleDbDataAdapter("SELECT * FROM tblTypePhone", cn);
      daTypePhone.FillSchema(ds.Tables["TypePhone"], SchemaType.Mapped);
// -----------------------------------------------
      ds.Tables.Add("PhoneAll");
      daPhoneAll = new OleDbDataAdapter("SELECT * FROM tblPhoneAll", cn);
      daPhoneAll.FillSchema(ds.Tables["PhoneAll"], SchemaType.Mapped);
    }

    private void MakeStructureDgv()
    {
      dgvPhone.AutoGenerateColumns = false;
      dgvPhone.Columns.Add(new DataGridViewTextBoxColumn()
      {
        Name             = "ID",
        HeaderText       = "ID",
        DataPropertyName = "ID"
      });
      dgvPhone.Columns.Add(new DataGridViewTextBoxColumn()
      {
        Name = "Phone",
        HeaderText = "Phone",
        DataPropertyName = "Phone"
      });

      dgvPhone.Columns.Add(new DataGridViewComboBoxColumn()
      {
        Name              = "TypePhoneID",
        HeaderText        = "Type Phone",
        DataPropertyName  = "TypePhoneID",
        DataSource        = ds.Tables["TypePhone"],
        DisplayMember     = "TypePhone",
        ValueMember       = "ID"
      });
      dgvPhone.Columns.Add(new DataGridViewTextBoxColumn()
      {
        Name = "PhoneMemo",
        DataPropertyName = "PhoneMemo"
      });

    }

    private void MakeRelation()   
    {
      DataRelation drContactPhone = new DataRelation("RelContactPhone", ds.Tables["Contact"].Columns["ID"],
                                                    ds.Tables["Phone"].Columns["ContactID"]);
      ds.Relations.Add(drContactPhone);
      DataRelation drContactPhoneAll = new DataRelation("RelContactPhoneAll", ds.Tables["Contact"].Columns["ID"],
                                                    ds.Tables["PhoneAll"].Columns["ContactID"]);
      ds.Relations.Add(drContactPhoneAll);

// -------------------------------------------------------
      dgvContact.DataSource = bsContact;
      bsContact.DataSource = ds;
      bsContact.DataMember = ds.Tables["Contact"].TableName;
// -------------------------------------------------------
      dgvPhone.DataSource = bsPhone;
      bsPhone.DataSource  = bsContact;
      bsPhone.DataMember  = ds.Relations["RelContactPhone"].RelationName;
// -------------------------------------------------------
      dgvPhoneAll.DataSource = bsPhoneAll;
      bsPhoneAll.DataSource  = bsContact;
      bsPhoneAll.DataMember  = ds.Relations["RelContactPhoneAll"].RelationName;

    }

    private void FormMain_Load(object sender, EventArgs e)
    {
      DBcon("NoteBook.mdb");
      MakeStructureTable();
      MakeStructureDgv();
      MakeRelation();
      OleDbCommandBuilder cmdContact  = new OleDbCommandBuilder(daContact);
      OleDbCommandBuilder cmdPhone    = new OleDbCommandBuilder(daPhone);
      OleDbCommandBuilder cmdPhoneAll = new OleDbCommandBuilder(daPhoneAll);
      FillTables(); 
      ds.Dispose();
      cn.Close();
    }

    private void btnRefresh_Click(object sender, EventArgs e)
    {
      ds.Clear();
      FillTables();
    }

    private void FormMain_FormClosing(object sender, FormClosingEventArgs e)
    {
      if (ds.HasChanges())
      {
        DialogResult result = MessageBox.Show("Save?", "Data changed!", MessageBoxButtons.YesNoCancel,
                                               MessageBoxIcon.Information);
        switch (result)
        {
          case System.Windows.Forms.DialogResult.Yes:
            if (ds.Tables["Contact"].GetChanges() != null)
              daContact.Update(ds.Tables["Contact"]);
            if (ds.Tables["Phone"].GetChanges() != null)
              daPhone.Update(ds.Tables["Phone"]);
            if (ds.Tables["PhoneAll"].GetChanges() != null)
              daPhoneAll.Update(ds.Tables["PhoneAll"]);
             break;

          case System.Windows.Forms.DialogResult.No:
            Environment.Exit(1);
            break;
          case System.Windows.Forms.DialogResult.Cancel:
            e.Cancel = true;
            break;
        }
      } 
    }

    private void btnSave_Click(object sender, EventArgs e)
    {
      if (ds.HasChanges())
      {
        if (ds.Tables["Contact"].GetChanges() != null)
          daContact.Update(ds.Tables["Contact"]);
        if (ds.Tables["Phone"].GetChanges() != null)
          daPhone.Update(ds.Tables["Phone"]);
        if (ds.Tables["PhoneAll"].GetChanges() != null)
          daPhoneAll.Update(ds.Tables["PhoneAll"]);

      }
    }

  } //class
} // namespace
